# autoeval example

This directory contains examples on how to use the autoeval module of biotrainer.

* Supervised evaluation: [plm_eval.ipynb](plm_eval.ipynb)
* Zero-shot evaluation: [plm_eval_zeroshot.ipynb](plm_eval_zeroshot.ipynb)
